@@ -21,7 +21,9 @@
 #include <string.h>
 
 #include <gtk/gtkcombo.h>
+#include <gtk/gtkcombobox.h>
 #include <gtk/gtkentry.h>
+#include <gtk/gtkexpander.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtklist.h>
 #include <gtk/gtklistitem.h>
@@ -189,6 +191,13 @@ gb_label_find_mnemonic_widget (GtkWidget *widget)
 
   while (parent)
     {
+      if (GTK_IS_EXPANDER (parent))
+	{
+	  if (gtk_expander_get_label_widget (GTK_EXPANDER (parent)) == widget)
+	    return TRUE;
+	  else
+	    return FALSE;
+	}
       if (GTK_WIDGET_GET_CLASS (parent)->activate_signal)
 	{
 	  return TRUE;
@@ -346,7 +355,13 @@ static void
 gb_label_get_focus_targets (GtkWidget * widget,
 			    GList ** focus_targets)
 {
-  if (GTK_WIDGET_CAN_FOCUS (widget) && GB_IS_GB_WIDGET (widget))
+  /* GtkWidget now has a "mnemonic_activate" signal, which some widgets use
+     to set focus to themselves or a child. So it is difficult to know if
+     a widget can be a focus target. We can't just use CAN_FOCUS as before.
+     For now I've just added some specific widgets. */
+  if (GB_IS_GB_WIDGET (widget)
+      && (GTK_WIDGET_CAN_FOCUS (widget)
+	  || GTK_IS_COMBO_BOX (widget)))
     {
       *focus_targets = g_list_insert_sorted (*focus_targets,
 					     (gchar*) gtk_widget_get_name (widget),
@@ -651,18 +666,29 @@ gb_label_write_standard_source (GtkWidget * widget,
 static void
 gb_label_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 {
+  gboolean translatable, context;
+  gchar *comments;
+
   if (data->create_widget)
     {
       const gchar *label_text = gtk_label_get_label (GTK_LABEL (widget));
 
+      glade_util_get_translation_properties (widget, Label, &translatable,
+					     &comments, &context);
+      source_add_translator_comments (data, translatable, comments);
+
       if (gtk_label_get_use_underline (GTK_LABEL (widget)))
 	source_add (data, "  %s = gtk_label_new_with_mnemonic (%s);\n",
 		    data->wname,
-		    source_make_string (label_text, data->use_gettext));
+		    source_make_string_full (label_text,
+					     data->use_gettext && translatable,
+					     context));
       else
 	source_add (data, "  %s = gtk_label_new (%s);\n",
 		    data->wname,
-		    source_make_string (label_text, data->use_gettext));
+		    source_make_string_full (label_text,
+					     data->use_gettext && translatable,
+					     context));
     }
 
   gb_widget_write_standard_source (widget, data);
