@@ -49,6 +49,7 @@
 #endif
 
 #include "../gb.h"
+#include "../tree.h"
 
 /* Include the 21x21 icon pixmap for this widget, to be used in the palette */
 #include "../graphics/toolbar.xpm"
@@ -610,7 +611,7 @@ gb_toolbar_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   /* We set up a tmp_toolbar_icon_size variable that we can use when creating
      the tool items. */
-  source_ensure_decl (data, "  gint tmp_toolbar_icon_size;\n");
+  source_ensure_decl (data, "  GtkIconSize tmp_toolbar_icon_size;\n");
   source_add (data,
 	      "  tmp_toolbar_icon_size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (%s));\n",
 	      data->wname);
