@@ -104,6 +104,22 @@ static void session_die_cb (GnomeClient *client, gpointer client_data);
 GnomeClient *GladeClient;
 #endif
 
+
+static void
+glade_log_handler (const gchar *log_domain,
+		   GLogLevelFlags log_level,
+		   const gchar *message,
+		   gpointer user_data)
+{
+  /* We just want to ignore this warning as it happens in normal circumstances
+     and just confuses users. */
+  if (!strcmp (message, "gtk_scrolled_window_add(): cannot add non scrollable widget use gtk_scrolled_window_add_with_viewport() instead"))
+    return;
+
+  g_log_default_handler (log_domain, log_level, message, user_data);
+}
+
+
 int
 main (int argc, char *argv[])
 {
@@ -164,9 +180,12 @@ main (int argc, char *argv[])
 
   /* For GTK 1.2, default GTK rc files are parsed automatically. */
   home_dir = (gchar*) g_get_home_dir ();
-  rc_path = g_strdup_printf ("%s/.gladerc", home_dir);
-  gtk_rc_add_default_file (rc_path);
-  g_free (rc_path);
+  if (home_dir)
+    {
+      rc_path = g_strdup_printf ("%s/.gladerc", home_dir);
+      gtk_rc_add_default_file (rc_path);
+      g_free (rc_path);
+    }
   gtk_init (&argc, &argv);
 #endif
 
@@ -192,6 +211,8 @@ main (int argc, char *argv[])
      So we delay loading of files until then. */
   gtk_idle_add ((GtkFunction) final_setup_from_main_loop, NULL);
 
+  g_log_set_handler ("Gtk", G_LOG_LEVEL_WARNING, glade_log_handler, NULL);
+
 #ifdef USE_GNOME
   bonobo_main ();
 #else
@@ -274,6 +295,17 @@ get_session_file (GnomeClient *client)
 }
 #endif
 
+
+static void
+show_window (GtkWidget *window, gboolean show)
+{
+  if (show)
+    gtk_widget_show (window);
+  else
+    gtk_widget_hide (window);
+}
+
+
 /* This creates the main GUI windows and loads any XML file specified from the
    command-line. We do this here because we can't make any Bonob calls until
    the main loop is running. */
@@ -286,18 +318,35 @@ final_setup_from_main_loop (gpointer data)
   gchar *session_file = NULL, *session_file_utf8 = NULL;
 #endif
   gboolean loaded_file = FALSE;
+  gboolean show_palette = TRUE, show_property_editor = TRUE;
+  gboolean show_widget_tree = FALSE, show_clipboard = FALSE;
 
   project_window = glade_project_window_new ();
+
+  /* Load the window geometries. */
+  glade_load_settings (project_window,
+		       glade_palette, &show_palette,
+		       win_property, &show_property_editor,
+		       win_tree, &show_widget_tree,
+		       glade_clipboard, &show_clipboard);
+
+  /* Always show the main project window. */
   gtk_widget_show (project_window->window);
 
-  if (!arg_hide_palette)
-    glade_show_palette ();
-  if (!arg_hide_property_editor)
-    glade_show_property_editor ();
+  /* Command-line args override the settings file. */
+  if (arg_hide_palette)
+    show_palette = FALSE;
+  if (arg_hide_property_editor)
+    show_property_editor = FALSE;
   if (arg_show_widget_tree)
-    glade_show_widget_tree ();
+    show_widget_tree = TRUE;
   if (arg_show_clipboard)
-    glade_show_clipboard ();
+    show_clipboard = TRUE;
+
+  show_window (glade_palette, show_palette);
+  show_window (win_property, show_property_editor);
+  show_window (win_tree, show_widget_tree);
+  show_window (glade_clipboard, show_clipboard);
 
    if (arg_filename)
     {
@@ -366,6 +415,8 @@ final_setup_from_main_loop (gpointer data)
 
   glade_project_window_set_project (project_window, current_project);
 
+  glade_project_window_refresh_menu_items ();
+
   return FALSE;
 }
 
